@@ -1,68 +1,50 @@
 ######################################################################
 # adminchangepassword.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: adminchangepassword.inc.pl,v 1.35 2010/12/14 22:20:00 papu Exp $
+# $Id: adminchangepassword.inc.pl,v 1.465 2012/03/18 06:03:52 papu Exp $
 #
-# "PyukiWiki" version 0.1.8 $$
+# "PyukiWiki" ver 0.2.0-p3 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2010 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2010 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
-
 $adminchangepassword::dummypass="aetipaesgyaigygoqyiwgorygaeta";
 $adminchangepassword::setupinicgi=$::setup_file;
 $adminchangepassword::minlength=6;
 $adminchangepassword::maxlength=32;
 $adminchangepassword::tableleftwidth=150;
-
 sub plugin_adminchangepassword_action {
 	my $stat,$body;
 	%::auth=&authadminpassword(submit);
 	return('msg'=>"\t$::resource{adminchangepassword_plugin_title}",'body'=>$auth{html})
 		if($auth{authed} eq 0);
-
+	my($h,$b,$stat,$body);
 	if(defined($::form{extpass})) {
 		($stat,$body)=&plugin_adminchangepassword_set;
-		$body.=&plugin_adminchangepassword_input
-			if($stat ne 0);
+		if($stat ne 0) {
+			($h,$b)=&plugin_adminchangepassword_input($auth{crypt});
+			$body.=$b;
+		}
 	} else {
-		$body=&plugin_adminchangepassword_input;
+		($h,$body)=&plugin_adminchangepassword_input($auth{crypt});
 	}
-
 	my $in_head=<<EOM;
-<script  type="text/javascript"><!--
-function Display(id,mode){
-	if(document.all || document.getElementById){	//IE4, NN6 or later
-		if(document.all){
-			obj = document.all(id).style;
-		}else if(document.getElementById){
-			obj = document.getElementById(id).style;
-		}
-		if(mode == "view") {
-			obj.display = "block";
-		} else if(mode == "none") {
-			obj.display = "none";
-		} else if(obj.display == "block"){
-			obj.display = "none";		//hidden
-		}else if(obj.display == "none"){
-			obj.display = "block";		//view
-		}
-	}
-}
+<script type="text/javascript"><!--
+function ViewPassForm(f,e){var b,c="block",a="none";if(d.all||d.getElementById){if(d.all){b=d.all(f).style}else{if(d.getElementById){b=d.getElementById(f).style}}if(e=="view"){b.display=c}else{if(e==a){b.display=a}else{if(b.display==c){b.display=a}else{if(b.display==a){b.display=c}}}}}};
+@{[$h ne '' ? "\nfunction SetPass(e){$h}" : ""]}
 //--></script>
 EOM
 	return ('msg'=>"\t$::resource{adminchangepassword_plugin_title}", 'body'=>$body,
 			'header'=>$in_head);
 }
-
 sub plugin_adminchangepassword_set {
 	my($stat,$body);
 	$stat=0;
@@ -76,20 +58,19 @@ sub plugin_adminchangepassword_set {
 	$body.=&plugin_adminchangepassword_write if($stat eq 0);
 	return($stat,$body);
 }
-
 sub plugin_adminchangepassword_write {
 	my ($body,$write);
 	if($::form{extpass} eq 1) {
 		$write=<<EOM;
 \$::adminpass = '$adminchangepassword::dummypass';
-\$::adminpass{admin}='@{[&plugin_adminchangepassword_crypt($::form{passwd_admin})]}';
-\$::adminpass{frozen}='@{[&plugin_adminchangepassword_crypt($::form{passwd_frozen})]}';
-\$::adminpass{attach}='@{[&plugin_adminchangepassword_crypt($::form{passwd_attach})]}';
+\$::adminpass{admin}='@{[&plugin_adminchangepassword_crypt(&password_decode($::form{passwd_admin},$::form{passwd_admin_enc},$::form{passwd_admin_token}))]}';
+\$::adminpass{frozen}='@{[&plugin_adminchangepassword_crypt(&password_decode($::form{passwd_frozen},$::form{passwd_frozen_enc},$::form{passwd_admin_token}))]}';
+\$::adminpass{attach}='@{[&plugin_adminchangepassword_crypt(&password_decode($::form{passwd_attach},$::form{passwd_attach_enc},$::form{passwd_attach_token}))]}';
 1;
 EOM
 	} else {
 		$write=<<EOM;
-\$::adminpass = '@{[&plugin_adminchangepassword_crypt($::form{passwd_common})]}';
+\$::adminpass = '@{[&plugin_adminchangepassword_crypt(&password_decode($::form{passwd_common},$::form{passwd_common_enc},$::form{passwd_common_token}))]}';
 \$::adminpass{admin}='';
 \$::adminpass{frozen}='';
 \$::adminpass{attach}='';
@@ -101,17 +82,17 @@ EOM
 		close(W);
 		$body=<<EOM;
 $::resource{adminchangepassword_plugin_msg_complete}<br />
-<form action="$::script" method="POST">
+<form action="$::script" method="POST" id="adminchangepasswd" name="adminchangepasswd">
 <input type="hidden" name="cmd" value="adminchangepassword" />
 <input type="submit" value="$::resource{adminchangepassword_plugin_btn_back}" />
 </form>
 EOM
 	} else {
 		my $msg=$::resource{adminchangepassword_plugin_err_write};
-		$msg=~s/FILE/$adminchangepassword::setupinicgi/g;
+		$msg=~s/\$FILE/$adminchangepassword::setupinicgi/g;
 		$body=<<EOM;
 <div class="error">$msg<br />
-<form action="$::script" method="POST">
+<form action="$::script" method="POST" id="adminchangepasswd" name="adminchangepasswd">
 <input type="hidden" name="cmd" value="adminchangepassword" />
 <input type="submit" value="$::resource{adminchangepassword_plugin_btn_back}" />
 </form>
@@ -119,13 +100,12 @@ EOM
 	}
 	return $body;
 }
-
-sub plugin_adminchangepassword_crypt {
-}
-
 sub plugin_adminchangepassword_check {
 	my($form,$stat,$body)=@_;
-
+	if($::form{"passwd_" . $form} eq '') {
+		$::form{"passwd_" . $form}=&password_decode($::form{"passwd_" . $form},$::form{"passwd_" . $form . "_enc"},$::form{"passwd_" . $form . "_token"});
+		$::form{"passwd2_" . $form}=&password_decode($::form{"passwd2_" . $form},$::form{"passwd2_" . $form . "_enc"},$::form{"passwd_" . $form . "_token"});
+	}
 	if($::form{"passwd_" . $form} eq '') {
 		$stat=1;
 		$body.=<<EOM;
@@ -133,19 +113,19 @@ sub plugin_adminchangepassword_check {
 $::resource{"adminchangepassword_plugin_" . $form}
 $::resource{adminchangepassword_plugin_err_nopass}
 </div>
-</br >
+<br />
 EOM
 	} elsif(length($::form{"passwd_" . $form}) < $adminchangepassword::minlength
 	|| length($::form{"passwd_" . $form}) > $adminchangepassword::maxlength) {
 		$stat=1;
 		my $msg=$::resource{adminchangepassword_plugin_err_strmin};
-		$msg=~s/MIN/$adminchangepassword::minlength/g;
-		$msg=~s/MAX/$adminchangepassword::maxlength/g;
+		$msg=~s/\$MIN/$adminchangepassword::minlength/g;
+		$msg=~s/\$MAX/$adminchangepassword::maxlength/g;
 		$body.=<<EOM;
 <div class="error">
 $::resource{"adminchangepassword_plugin_" . $form}$msg
 </div>
-</br >
+<br />
 EOM
 	} elsif($::form{"passwd_" . $form} ne $::form{"passwd2_" . $form}) {
 		$stat=1;
@@ -154,7 +134,7 @@ EOM
 $::resource{"adminchangepassword_plugin_" . $form}
 $::resource{adminchangepassword_plugin_err_ignore}
 </div>
-</br >
+<br />
 EOM
 	}
 	if($stat eq 1) {
@@ -163,21 +143,23 @@ EOM
 	}
 	return ($stat,$body);
 }
-
 sub plugin_adminchangepassword_input {
+	my($cryptflg)=@_;
 	my $body;
 	$body=<<EOM;
-<form action="$::script" method="POST">
+<form action="$::script" method="POST" id="adminchangepasswd" name="adminchangepasswd">
 <input type="hidden" name="cmd" value="adminchangepassword" />
 $auth{html}
 <table>
 <tr>
 <td width="$adminchangepassword::tableleftwidth">$::resource{adminchangepassword_plugin_extpass}:</td>
 <td>
-<input type="radio" name="extpass" value="0" onclick="Display('common','view');Display('admin','none');Display('frozen','none');Display('attach','none');"@{[!&plugin_adminchangepassword_checkmode ? " checked" : ""]} />
+<input type="radio" name="extpass" value="0" onclick="ViewPassForm('common','view');ViewPassForm('admin','none');ViewPassForm('frozen','none');ViewPassForm('attach','none');"@{[!&plugin_adminchangepassword_checkmode ? qq( checked="checked") : ""]} />
 $::resource{adminchangepassword_plugin_nouse}
-<input type="radio" name="extpass" value="1" onclick="Display('common','none');Display('admin','view');Display('frozen','view');Display('attach','view');"@{[&plugin_adminchangepassword_checkmode ? " checked" : ""]} />
+<input type="radio" name="extpass" value="1" onclick="ViewPassForm('common','none');ViewPassForm('admin','view');ViewPassForm('frozen','view');ViewPassForm('attach','view');"@{[&plugin_adminchangepassword_checkmode ? qq( checked="checked") : ""]} />
 $::resource{adminchangepassword_plugin_use}
+</td>
+</tr>
 </table>
 EOM
 	$body.=&plugin_adminchangepassword_makepasswdform("common"
@@ -188,20 +170,37 @@ EOM
 		,&plugin_adminchangepassword_checkmode ? "block" : "none");
 	$body.=&plugin_adminchangepassword_makepasswdform("attach"
 		,&plugin_adminchangepassword_checkmode ? "block" : "none");
-
 	$body.=<<EOM;
 <table>
 <tr>
 <td width="$adminchangepassword::tableleftwidth">&nbsp;</td>
+EOM
+	my $js;
+	if($cryptflg) {
+		$js.="if(keypress(e)==false) return;";
+		$js.="var f=gid('adminchangepasswd');";
+		foreach("common","admin","frozen","attach") {
+			$js.="pencf(f.passwd\_$_,f.passwd\_$_\_enc,f.passwd\_$_\_token);";
+			$js.="pencf(f.passwd2\_$_,f.passwd2\_$_\_enc,f.passwd2\_$_\_token);";
+		}
+		$js.="fsubmitdelay('adminchangepasswd',e);";
+		$body.=<<EOM;
+<td><input type="button" value="$::resource{adminchangepassword_plugin_btn_submit}" onclick="SetPass();" onkeypress="SetPass(event);" />
+</td>
+EOM
+	} else {
+		$body.=<<EOM;
 <td><input type="submit" value="$::resource{adminchangepassword_plugin_btn_submit}" />
 </td>
+EOM
+	}
+	$body.=<<EOM;
 </tr>
 </table>
 </form>
 EOM
-	return $body;
+	return ($js,$body);
 }
-
 sub plugin_adminchangepassword_crypt {
 	my($passwd)=@_;
 	my ($sec, $min, $hour, $day, $mon, $year, $weekday) = localtime(time);
@@ -211,13 +210,11 @@ sub plugin_adminchangepassword_crypt {
 	my $crypted = crypt($passwd, "$salt1$salt2");
 	return "$crypted $salt1$salt2";
 }
-
 sub plugin_adminchangepassword_checkmode {
 	return $::form{extpass} if(defined($::form{extpass}));
 	return 1 if($::adminpass{admin} ne '');
 	return 0;
 }
-
 sub plugin_adminchangepassword_makepasswdform {
 	my ($v,$s)=@_;
 	return <<EOM;
@@ -233,7 +230,5 @@ sub plugin_adminchangepassword_makepasswdform {
 </table>
 EOM
 }
-
 1;
 __END__
-
