@@ -1,81 +1,80 @@
 ######################################################################
 # article.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: article.inc.pl,v 1.66 2007/07/15 07:40:09 papu Exp $
+# $Id: article.inc.pl,v 1.431 2012/01/31 10:11:58 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
-# Author: Nekyo
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# "PyukiWiki" version 0.2.0-p1 $$
+# Author: Nekyo http://nekyo.qp.land.to/
+# Copyright (C) 2004-2012 Nekyo
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
-
 use strict;
-
 # ƥȥꥢΥ
 $article::cols = 70
 	if(!defined($article::cols));
-
+#
 # ƥȥꥢιԿ
 $article::rows = 5
 	if(!defined($article::rows));
-
+#
 # ̾ƥȥꥢΥ
 $article::name_cols = 24
 	if(!defined($article::name_cols));
-
+#
 # ̾ƥȥꥢΥ
 $article::subject_cols = 60
 	if(!defined($article::subject_cols));
-
+#
 # ̾եޥå
 $article::name_format = "\'\'[[\$1>$::resource{profile_page}/\$1]]\'\'"
 	if(!defined($article::name_format));
-
+#
 # ̾եޥå
 $article::subject_format = '**$subject'
 	if(!defined($article::subject_format));
-
+#
 # դեޥå (&new ǧǤ뤳)
 $article::date_format= "Y-m-d(lL) H:i:s"
 	if(!defined($article::date_format));
-
+#
 #  1: 0:θ
 $article::ins = 0
 	if(!defined($article::ins));
-
+#
 # ߲˰ԥȤ 1: 0:ʤ
 $article::comment = 1
 	if(!defined($article::comment));
-
+#
 # ԤưŪѴ 1: 0:ʤ
 $article::auto_br = 1
 	if(!defined($article::auto_br));
-
+#
 # ̾ʤǽʤ
 $article::noname = 1
 	if(!defined($article::noname));
-
+#
 # ֥Ȥʤǽʤ
 $article::nosubject = 0
 	if(!defined($article::nosubject));
-
+#
 # ֥ȤʤΥȥ
 $article::no_subject = "no subject"
 	if(!defined($article::no_subject));
-
+######################################################################
 $article::no = 0;
-
 my $_no_name = "";
-
 sub plugin_article_action {
+	&::spam_filter($::form{msg}, 2);
+	&::spam_filter($::form{myname}, 0);
+	&::spam_filter($::form{subject}, 0);
 	if (($::form{msg} =~ /^\s*$/)
 	 || ($::form{myname} =~ /^\s*$/ && $article::noname eq 1)
 	 || ($::form{subject} =~ /^\s*$/ && $article::nosubject eq 1)) {
@@ -94,18 +93,15 @@ sub plugin_article_action {
 	}
 	$::form{subject} = &code_convert(\$::form{myname}, $::defaultcode);
 	$::form{msg} = &code_convert(\$::form{msg}, $::defaultcode);
-
 	$::form{msg}=~s/\x0D\x0A|\x0D|\x0A/\n/g;
 	$::form{msg}=~s/^(\s|\n)//g while($::form{msg}=~/^(\s|\n)/);
 	$::form{msg}=~s/(\s|\n)$//g while($::form{msg}=~/(\s|\n)$/);
 	$::form{msg}=~s/\n/\~\n/g if($article::auto_br);
-
 	my $artic = "$subject\n>$name &new{@{[&date($article::date_format)]}};~\n~\n$::form{msg}\n";
 	$artic .= "\n#comment\n" if ($article::comment);
 	my $postdata = '';
 	my @postdata_old = split(/\r?\n/, $::database{$::form{'mypage'}});
 	my $_article_no = 0;
-
 	foreach (@postdata_old) {
 		$postdata .= $_ . "\n" if (!$article::ins);
 		if (/^#article/ && (++$_article_no == $::form{article_no})) {
@@ -119,11 +115,9 @@ sub plugin_article_action {
 	&close_db;
 	exit;
 }
-
 sub plugin_article_convert {
 	return ' '
 		if($::writefrozenplugin eq 0 && &get_info($::form{mypage}, $::info_IsFrozen) eq 1);
-
 	$article::no++;
 	my $conflictchecker = &get_info($::form{mypage}, $::info_ConflictChecker);
 	return <<"EOD";
@@ -142,7 +136,5 @@ sub plugin_article_convert {
 </form>
 EOD
 }
-
 1;
 __END__
-
