@@ -1,15 +1,15 @@
 ######################################################################
 # calendar.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: calendar.inc.pl,v 1.20 2011/01/25 03:11:15 papu Exp $
+# $Id: calendar.inc.pl,v 1.278 2011/12/31 13:06:10 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p2 $$
+# "PyukiWiki" version 0.2.0 $$
 # Author: Nekyo
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 by Nekyo.
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
 # License: GPL2 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
@@ -17,20 +17,17 @@
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
 #
-# ֤롣
+# ֤롣ܸ쥪꡼
 # :|
 #  #calendar([{[ڡ̾],[ǯ]}])
 # -ڡ̾ꤹ롣ά֥ڡȤʤ롣
 # -ǯɽȷyyyymmǻꤹ롣άϸǯ
-
 # calendar.inc.pl v0.0.3 cooked up by Birgus-Latro.
 # for "PyukiWiki" copyright 2004 by Nekyo.
 # based on calendar.inc.php  v1.18  2003/06/04 14:20:36 arino.
 #          calendar2.inc.php v1.20  2003/06/03 11:59:07 arino.
 #          calendar.pl       v1.2                       Seiji Zenitani.
 use strict;
-use Time::Local;
-
 sub plugin_calendar_convert {
 	my ($page, $arg_date) = split(/,/, shift);
 	my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst);
@@ -38,10 +35,8 @@ sub plugin_calendar_convert {
 	my ($prefix,$splitter);
 	my $empty = '&nbsp;';
 	my $calendar = "";
-
 	($sec, $min, $hour, $mday, $mon, $year) = localtime();
 	$today = ($year+1900)*10000 + ($mon+1)*100 + $mday;
-
 	if    ($page eq '') {
 		$prefix = $::form{mypage};
 		$splitter = '/';
@@ -60,19 +55,16 @@ sub plugin_calendar_convert {
 	} else {
 		$cookedpage = &encode($page);
 	}
-
 	if ($arg_date =~ /^(\d{4})[^\d]?(\d{1,2})$/ ) {
 		$year = $1 - 1900;
 		$mon = ($2-1) % 12;
 	}
 	my $disp_year  = $year+1900;
 	my $disp_month = $mon+1;
-
 	my $start_time = timelocal(0,0,0,1,$mon,$year);
 	($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime($start_time);
 	$label = "$disp_year.$disp_month";
 	$start = ($year+1900)*10000 + ($mon+1)*100 + $mday;
-
 	if ( $mon == 11 ) {
 		$end = ($year+1900)*10000 + ($mon+1)*100 + 31;
 	} else {
@@ -80,7 +72,6 @@ sub plugin_calendar_convert {
 		($sec, $min, $hour, $mday, $mon, $year ) = localtime($end_time);
 		$end = ($year+1900)*10000 + ($mon+1)*100 + $mday;
 	}
-
 	my $pagelink;
 	if ($::database{$page}) {
 		$pagelink = qq(<br />[<a title="$page" href="$::script?$cookedpage">$page</a>]);
@@ -89,10 +80,8 @@ sub plugin_calendar_convert {
 	} else {
 		$pagelink = qq(<br />[$page<a title="$::resource{editthispage}" class="editlink" href="$::script?cmd=adminedit&amp;mypage=$cookedpage">?</a>]);
 	}
-
 	my $prev_date_str = ($disp_month ==  1)? sprintf('%04d%02d',$disp_year - 1,12) : sprintf('%04d%02d',$disp_year,$disp_month - 1);
 	my $next_date_str = ($disp_month == 12)? sprintf('%04d%02d',$disp_year + 1, 1) : sprintf('%04d%02d',$disp_year,$disp_month + 1);
-
 	$calendar =<<"END";
 <table class="style_calendar" summary="calendar body">
 <tr>
@@ -113,7 +102,6 @@ sub plugin_calendar_convert {
 </tr>
 <tr>
 END
-
 	for ( $i = 0; $i < $wday; $i++ ) {
 		$calendar .= "<td class=\"style_td_blank\">$empty</td>";
 	}
@@ -123,11 +111,9 @@ END
 		$disp_wday = ($wday + $i - $start) % 7;
 		my $pagename = sprintf "%s%s%04d-%02d-%02d", $page, $splitter, $disp_year, $disp_month, $d;
 		my $cookedname = &encode($pagename);
-
 		if (($disp_wday == 0) && ($i > $start)) {
  			$calendar .= "</tr>\n<tr>\n";
 		}
-
 		if ( $i == $today ) {
 			$style = 'style_td_today';
 		} elsif ($disp_wday == 0) {
@@ -137,7 +123,6 @@ END
 		} else {
 			$style = 'style_td_day';
 		}
-
 		if ($::database{$pagename}) {
 			$calendar .= qq(<td class="$style"><a title="$pagename" href="$::script?$cookedname"><strong>$d</strong></a></td>);
 		} else {
@@ -147,20 +132,16 @@ END
 	for ( $i = $disp_wday + 1; $i < 7; $i++ ) {
 		$calendar .= "<td class=\"style_td_blank\">$empty</td>";
 	}
-
 	$calendar .= "</tr>\n</table>\n";
 	return $calendar;
 }
-
 sub plugin_calendar_action {
 	my $page = &escape($::form{mymsg});
 	my $date = &escape($::form{date});
 	my $body = &plugin_calendar_convert(qq($page,$date));
-
 	my $yy = sprintf("%04d.%02d",substr($date,0,4),substr($date,4,2));
 	my $s_page = htmlspecialchars($page);
 	return ('msg'=>qq(calendar $s_page/$yy), 'body'=>$body);
 }
 1;
 __END__
-
