@@ -1,16 +1,16 @@
 ######################################################################
 # sbookmark.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: sbookmark.inc.pl,v 1.36 2011/01/25 03:11:15 papu Exp $
+# $Id: sbookmark.inc.pl,v 1.428 2012/03/01 08:41:56 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p2 $$
-# Author: Nekyo
-# Copyright (C) 2004-2011 by Nekyo.
+# "PyukiWiki" version 0.2.0-p2 $$
+# Author: Nekyo http://nekyo.qp.land.to/
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -23,57 +23,50 @@
 # v 0.0.2 - URLΥåɲáܸURLб
 # v 0.0.1 - ProtoType
 #
-# https:// åˤϡlib/Nana/HTTP.pm 
+# https:// 䡢IPV6Ȥåˤϡlib/Nana/HTTP.pm 
 # $Nana::HTTP::useLWP=1 ˤƲ
 ######################################################################
-
-use strict;
-
 # Υեޥå
 my $sbookmark_format = "[[\x08TITLE\x08>\x08URL\x08]]-- \x08NAME\x08 \x08NOW\x08~\n\x08COMMENT\x08";
-
-
+#
 # ̾ʤǽʤ
 $sbookmark::noname = 1
 	if(!defined($sbookmark::noname));
-
+#
 # URLܤƤʤ票顼
 $sbookmark::nodata = 1
 	if(!defined($sbookmark::nodata));
-
+#
 # ȥ뤬ܤƤʤ票顼
 $sbookmark::notitle = 0
 	if(!defined($sbookmark::notitle));
-
+#
 # URLºߤ뤫å
 $sbookmark::urlcheck = 1
 	if(!defined($sbookmark::urlcheck));
-
-# ȤΥƥȥꥢɽ 
+#
+# ȤΥƥȥꥢɽ
 $sbookmark::size_msg = 40
 	if(!defined($sbookmark::size_name));
-
-# Ȥ̾ƥȥꥢɽ 
+#
+# Ȥ̾ƥȥꥢɽ
 $sbookmark::size_name = 24
 	if(!defined($sbookmark::size_name));
-
+#
 # Ȥեޥå
 $sbookmark::format_msg = q{$1}
 	if(!defined($sbookmark::format_msg));
-
+#
 # ݤURL
 $sbookmark::ignoreurl='(\/\/|\.exe|\.scr|\.bat|\.pif)$'
 	if(!defined($sbookmark::ignoreurl));
-
+#
 # ꤷURLƱƤʤ顢URL¸ߤʤȲꤹ롣
 # (DNS磻ɥɥ쥳ɤǰƤ륵СǤк
 # (punyURLˤбƤޤ)
 $sbookmark::wildcarddnsurl=''
 	if(!defined($sbookmark::wildcardurl));
-
 sub plugin_sbookmark_action {
-
-
 	if (($::form{url} =~ /^\s*$/ && $sbookmark::nodata eq 1)
 	 || ($::form{title} =~ /^\s*$/ && $sbookmark::notitle eq 1)
 	 || ($::form{myname} =~ /^\s*$/ && $sbookmark::noname eq 1)) {
@@ -85,13 +78,10 @@ sub plugin_sbookmark_action {
 	if ($::form{url} ne '' && $::form{title} eq '') {
 		$::form{title}=$::form{url};
 	}
-
-
 	if($sbookmark::urlcheck eq 1) {
 		&load_module("Nana::HTTP");
 		my $url=$::form{url};
 		if($::_exec_plugined{punyurl} ne '') {
-
 			&load_module("IDNA::Punycode");
 			if($url=~/$::isurl_puny/o) {
 				$url=~/(https?|ftp):\/\/([^:\/\#]+)(.*)/;
@@ -121,7 +111,6 @@ sub plugin_sbookmark_action {
 		if($result ne 0 || length($stream) eq 0) {
 			return('msg'=>"$::form{mypage}\t\t$::resource{sbookmark_plugin_urlnot}",'body'=>&text_to_html($::database{$::form{mypage}}),'ispage'=>1);
 		}
-
 		if($sbookmark::wildcarddnsurl ne '') {
 			my $whttp=new Nana::HTTP('plugin'=>"sbookmark");
 			my ($resultw, $streamw) = $whttp->get($sbookmark::wildcarddnsurl);
@@ -130,21 +119,15 @@ sub plugin_sbookmark_action {
 			}
 		}
 	}
-
-
 	my $lines = $::database{$::form{mypage}};
 	my @lines = split(/\r?\n/, $lines);
-
 	my $datestr = ($::form{nodate} == 1) ? '' : &get_now;
 	my $__name=$sbookmark::format_msg;
 	$__name=~s/\$1/$::form{myname}/g;
 	my $_name = $::form{myname} ? " $__name : " : " ";
-
 	my $_now = "&new{$datestr};";
-
 	my $postdata = '';
 	my $_sbookmark_no = 0;
-
 	my $sbookmark = $sbookmark_format;
 	$sbookmark =~ s/\x08TITLE\x08/$::form{title}/;
 	$sbookmark =~ s/\x08URL\x08/$::form{url}/;
@@ -152,7 +135,6 @@ sub plugin_sbookmark_action {
 	$sbookmark =~ s/\x08NAME\x08/$_name/;
 	$sbookmark =~ s/\x08NOW\x08/$_now/;
 	$sbookmark = "+" . $sbookmark;
-
 	foreach (@lines) {
 		if (/^#sbookmark/ && (++$_sbookmark_no == $::form{sbookmark_no})) {
 			if ($::form{above} == 1) {
@@ -174,26 +156,21 @@ sub plugin_sbookmark_action {
 	&close_db;
 	exit;
 }
-
 my $sbookmark_no = 0;
 my %sbookmark_numbers = {}; # Tnx:Birgus-Latro
-
 sub plugin_sbookmark_convert {
 	my @argv = split(/,/, shift);
-
 	my $above = 1;
 	my $nodate = '';
 	my $nametags = '<tr><td>'
 		. $::resource{sbookmark_plugin_yourname}
 		. '</td>'
 		. '<td><input type="text" name="myname" value="" size="10"></td></tr>';
-
 	my $nametags = '<tr><td>'
 		. $::resource{sbookmark_plugin_yourname}
 		. '</td><td>'
 		. qq(<input type="text" name="myname" value="$::name_cookie{myname}" size="$sbookmark::size_name" />)
 		. '</td></tr>';
-
 	foreach (@argv) {
 		chomp;
 		if (/below/) {
@@ -233,4 +210,3 @@ EOD
 }
 1;
 __END__
-
